﻿# Biblos 5 - The Accessible Braille Word Processor
# Components for NVDA 2024.1 (and later?)
# Copyright (C) 2013-2024 Giuseppe Di Grande
# giuseppe@digrande.it - https://www.digrande.it/
# Subscribe https://www.facebook.com/groups/BiblosBraille

import globalPluginHandler
import gui
import wx
from gui.settingsDialogs import SettingsPanel
from appModules import biblosConf
from appModules import biblosGlob
from appModules import biblosLoca

class BiblosSettingsPanel(SettingsPanel):
	title = "Biblos"
	conf = biblosConf.biblosConfig()
	loca = biblosLoca.biblosLocales()

	def makeSettings(self, settingsSizer):
		sHelper = gui.guiHelper.BoxSizerHelper(self, sizer=settingsSizer)
# Text transliteration checkbox
		self._cxTextTransliteration = sHelper.addItem(wx.CheckBox(self, label=self.loca.locale(biblosGlob.textTransliteration)))
		self._cxTextTransliteration.SetValue(self.conf.textTransliteration)
# Say indentation checkbox
		self._cxSayIndentation = sHelper.addItem(wx.CheckBox(self, label=self.loca.locale(biblosGlob.sayIndentation)))
		self._cxSayIndentation.SetValue(self.conf.sayIndentation)
# Say braille nav checkbox
		self._cxSayBrailleNav = sHelper.addItem(wx.CheckBox(self, label=self.loca.locale(biblosGlob.sayBrailleNav)))
		self._cxSayBrailleNav.SetValue(self.conf.sayBrailleNav)
# Braille mode combobox
		self._cbBrailleMode = sHelper.addLabeledControl(self.loca.locale(biblosGlob.brailleMode), wx.Choice, choices=self.loca.locale(biblosGlob.brailleModeOpts))
		self._cbBrailleMode.SetSelection(self.conf.brailleMode)
# Braille tolerance combobox
		self._seBrailleTolerance = sHelper.addLabeledControl(self.loca.locale(biblosGlob.brailleTolerance), wx.SpinCtrl)
		self._seBrailleTolerance.SetMin(0)
		self._seBrailleTolerance.SetMax(20)
		self._seBrailleTolerance.SetValue(self.conf.brailleTolerance)
# Braille formatting checkbox
		self._cxBrailleFormatting = sHelper.addItem (wx.CheckBox(self, label=self.loca.locale(biblosGlob.brailleFormatting)))
		self._cxBrailleFormatting.SetValue(self.conf.brailleFormatting)
# Braille table coords checkbox
		self._cxBrailleTableCoords = sHelper.addItem (wx.CheckBox(self, label=self.loca.locale(biblosGlob.brailleTableCoords)))
		self._cxBrailleTableCoords.SetValue(self.conf.brailleTableCoords)
# Braille extras checkbox
		self._cxBrailleExtras = sHelper.addItem (wx.CheckBox(self, label=self.loca.locale(biblosGlob.brailleExtras)))
		self._cxBrailleExtras.SetValue(self.conf.brailleExtras)

	def onSave(self):
		self.conf.textTransliteration = self._cxTextTransliteration.GetValue()
		self.conf.sayIndentation = self._cxSayIndentation.GetValue()
		self.conf.sayBrailleNav = self._cxSayBrailleNav.GetValue()
		self.conf.brailleMode = self._cbBrailleMode.GetSelection()
		self.conf.brailleTolerance = self._seBrailleTolerance.GetValue()
		self.conf.brailleFormatting = self._cxBrailleFormatting.GetValue()
		self.conf.brailleTableCoords = self._cxBrailleTableCoords.GetValue()
		self.conf.brailleExtras = self._cxBrailleExtras.GetValue()


class GlobalPlugin(globalPluginHandler.GlobalPlugin):

	def __init__(self):
		super(GlobalPlugin, self).__init__()
		gui.settingsDialogs.NVDASettingsDialog.categoryClasses.append(BiblosSettingsPanel)

	def terminate(self):
		super(GlobalPlugin, self).terminate()
		gui.settingsDialogs.NVDASettingsDialog.categoryClasses.remove(BiblosSettingsPanel)
